-- 06/04/2021
UPDATE SBI_CONFIG SC SET VALUE_CHECK = 'it-IT,en-US,fr-FR,es-ES,pt-BR,en-GB,zh-Hans-CN,de-DE' WHERE LABEL = 'SPAGOBI.LANGUAGE_SUPPORTED.LANGUAGES';
UPDATE SBI_CONFIG SC SET VALUE_CHECK = 'en-US' WHERE LABEL = 'SPAGOBI.LANGUAGE_SUPPORTED.LANGUAGE.default';

UPDATE SBI_DOMAINS SET VALUE_CD = 'it-IT', DOMAIN_NM='Language tag code', VALUE_NM = 'Italian (IT)', VALUE_DS=VALUE_NM WHERE DOMAIN_CD = 'LANG' AND VALUE_NM = 'Italian' AND DOMAIN_NM = 'Language ISO code';
UPDATE SBI_DOMAINS SET VALUE_CD = 'en-US', DOMAIN_NM='Language tag code', VALUE_NM = 'English (US)', VALUE_DS=VALUE_NM WHERE DOMAIN_CD = 'LANG' AND VALUE_NM = 'English' AND DOMAIN_NM = 'Language ISO code';
UPDATE SBI_DOMAINS SET VALUE_CD = 'es-ES', DOMAIN_NM='Language tag code', VALUE_NM = 'Spanish (ES)', VALUE_DS=VALUE_NM WHERE DOMAIN_CD = 'LANG' AND VALUE_NM = 'Spanish' AND DOMAIN_NM = 'Language ISO code';
UPDATE SBI_DOMAINS SET VALUE_CD = 'fr-FR', DOMAIN_NM='Language tag code', VALUE_NM = 'French (FR)', VALUE_DS=VALUE_NM WHERE DOMAIN_CD = 'LANG' AND VALUE_NM = 'French' AND DOMAIN_NM = 'Language ISO code';
UPDATE SBI_DOMAINS SET VALUE_CD = 'pt-BR', DOMAIN_NM='Language tag code', VALUE_NM = 'Portoguese (BR)', VALUE_DS=VALUE_NM WHERE DOMAIN_CD = 'LANG' AND VALUE_NM = 'Portoguese' AND DOMAIN_NM = 'Language ISO code';

ALTER TABLE sbi_menu MODIFY COLUMN CUST_ICON TEXT NULL;

CREATE TABLE SBI_WIDGET_GALLERY (
  UUID CHAR(36) NOT NULL, -- primary key
  NAME VARCHAR(200) NOT NULL,
  DESCRIPTION VARCHAR(500) NULL,
  TYPE VARCHAR(45) NULL, -- HTML/CUSTOM CHART/PYTHON/R
  PREVIEW_IMAGE LONGBLOB NULL, -- binary of preview file
  TEMPLATE LONGTEXT NULL, -- text with template as a JSON
  AUTHOR VARCHAR(100) NULL,
  USAGE_COUNTER INT NULL, -- counter to see how many times the widgets was used
  USER_IN    VARCHAR(100) NOT NULL,
  USER_UP    VARCHAR(100),
  USER_DE    VARCHAR(100),
  TIME_IN    TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  TIME_UP    TIMESTAMP NULL DEFAULT NULL,    
  TIME_DE    TIMESTAMP NULL DEFAULT NULL,
  SBI_VERSION_IN  VARCHAR(10),
  SBI_VERSION_UP  VARCHAR(10),
  SBI_VERSION_DE  VARCHAR(10),
  ORGANIZATION    VARCHAR(20),
  OUTPUT_TYPE    VARCHAR(100),
  UNIQUE XAK1SBI_WIDGET_GALLERY (NAME, ORGANIZATION),
  PRIMARY KEY (UUID, ORGANIZATION)
);

CREATE TABLE SBI_WIDGET_GALLERY_TAGS (
  WIDGET_ID CHAR(36) NOT NULL, -- widget id reference
  TAG VARCHAR(50) NOT NULL, -- tag name
  USER_IN    VARCHAR(100) NOT NULL,
  USER_UP    VARCHAR(100),
  USER_DE    VARCHAR(100),
  TIME_IN    TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  TIME_UP    TIMESTAMP NULL DEFAULT NULL,    
  TIME_DE    TIMESTAMP NULL DEFAULT NULL,
  SBI_VERSION_IN  VARCHAR(10),
  SBI_VERSION_UP  VARCHAR(10),
  SBI_VERSION_DE  VARCHAR(10),
  ORGANIZATION    VARCHAR(20),
  KEY FK_SBI_WIDGET_GALLERY_TAGS_1_IDX (WIDGET_ID, TAG, ORGANIZATION),
  CONSTRAINT FK_SBI_WIDGET_GALLERY_TAGS_1 FOREIGN KEY (WIDGET_ID, ORGANIZATION) REFERENCES SBI_WIDGET_GALLERY (UUID, ORGANIZATION) ON DELETE CASCADE
) ENGINE=INNODB;

-- 21/06/2021
-- CATALOG FUNCTION REFACTORING - SUPPORT FOR UUIDS

-- DROP OLD FOREIGN KEYS
ALTER TABLE SBI_FUNCTION_INPUT_VARIABLE DROP FOREIGN KEY FK_FUNCTION_INPUT_VARIABLES_1;
ALTER TABLE SBI_FUNCTION_INPUT_COLUMN DROP FOREIGN KEY FK_FUNCTION_INPUT_COLUMNS_1;
ALTER TABLE SBI_FUNCTION_OUTPUT_COLUMN DROP FOREIGN KEY FK_FUNCTION_OUTPUT_COLUMNS_1;
ALTER TABLE SBI_OBJ_FUNCTION DROP FOREIGN KEY FK_SBI_OBJ_FUNCTION_1;

-- DROP OLD PRIMARY KEYS
ALTER TABLE SBI_CATALOG_FUNCTION DROP PRIMARY KEY;
ALTER TABLE SBI_FUNCTION_INPUT_COLUMN DROP PRIMARY KEY;
ALTER TABLE SBI_FUNCTION_INPUT_VARIABLE DROP PRIMARY KEY;
ALTER TABLE SBI_FUNCTION_OUTPUT_COLUMN DROP PRIMARY KEY;
ALTER TABLE SBI_OBJ_FUNCTION DROP KEY XAK1SBI_OBJ_FUNCTION;

-- ADD NEW UUID COLUMN
ALTER TABLE SBI_CATALOG_FUNCTION ADD COLUMN FUNCTION_UUID VARCHAR(36) FIRST;
ALTER TABLE SBI_FUNCTION_INPUT_COLUMN ADD COLUMN FUNCTION_UUID VARCHAR(36) FIRST;
ALTER TABLE SBI_FUNCTION_INPUT_VARIABLE ADD COLUMN FUNCTION_UUID VARCHAR(36) FIRST;
ALTER TABLE SBI_FUNCTION_OUTPUT_COLUMN ADD COLUMN FUNCTION_UUID VARCHAR(36) FIRST;
ALTER TABLE SBI_OBJ_FUNCTION ADD COLUMN FUNCTION_UUID VARCHAR(36) FIRST;

-- CONVERT ID TO UUID

-- in order to successfully execute the procedure below, user must have the following permissions:
-- GRANT SELECT,INSERT,UPDATE,DELETE,CREATE,CREATE VIEW,DROP,ALTER,REFERENCES,CREATE ROUTINE,ALTER ROUTINE,EXECUTE ON knowage_schema.* TO 'user'@'%';

DROP PROCEDURE IF EXISTS GENERATE_KNOWAGE_FUNCTIONS_CATALOG_UUIDS;
SET SQL_SAFE_UPDATES = 0;
DELIMITER //
CREATE PROCEDURE GENERATE_KNOWAGE_FUNCTIONS_CATALOG_UUIDS()
BEGIN
	DECLARE done BOOLEAN DEFAULT FALSE;
	DECLARE _function_id INTEGER;
	DECLARE _organization VARCHAR(20);
	DECLARE cur CURSOR FOR SELECT FUNCTION_ID, ORGANIZATION FROM SBI_CATALOG_FUNCTION;
	DECLARE CONTINUE HANDLER FOR NOT FOUND SET done := TRUE;

	OPEN cur;

	functionLoop: LOOP
		FETCH cur INTO _function_id, _organization;
		IF done THEN
			LEAVE functionLoop;
		END IF;
        SELECT UUID() INTO @uuid;
        UPDATE SBI_CATALOG_FUNCTION SET FUNCTION_UUID=@uuid WHERE FUNCTION_ID=_function_id AND ORGANIZATION=_organization;
        UPDATE SBI_FUNCTION_INPUT_VARIABLE SET FUNCTION_UUID=@uuid WHERE FUNCTION_ID=_function_id AND ORGANIZATION=_organization;
        UPDATE SBI_FUNCTION_INPUT_COLUMN SET FUNCTION_UUID=@uuid WHERE FUNCTION_ID=_function_id AND ORGANIZATION=_organization;
        UPDATE SBI_FUNCTION_OUTPUT_COLUMN SET FUNCTION_UUID=@uuid WHERE FUNCTION_ID=_function_id AND ORGANIZATION=_organization;
        UPDATE SBI_OBJ_FUNCTION SET FUNCTION_UUID=@uuid WHERE FUNCTION_ID=_function_id AND ORGANIZATION=_organization;
	END LOOP functionLoop;
    
	CLOSE cur;
END //
DELIMITER ;
CALL GENERATE_KNOWAGE_FUNCTIONS_CATALOG_UUIDS();
SET SQL_SAFE_UPDATES = 1;
DROP PROCEDURE GENERATE_KNOWAGE_FUNCTIONS_CATALOG_UUIDS;

-- CREATE NEW PRIMARY KEYS
ALTER TABLE SBI_CATALOG_FUNCTION ADD CONSTRAINT PK_SBI_CATALOG_FUNCTION PRIMARY KEY(FUNCTION_UUID, ORGANIZATION);
ALTER TABLE SBI_FUNCTION_INPUT_COLUMN ADD CONSTRAINT PK_SBI_FUNCTION_INPUT_COLUMN PRIMARY KEY(FUNCTION_UUID, COL_NAME, ORGANIZATION);
ALTER TABLE SBI_FUNCTION_INPUT_VARIABLE ADD CONSTRAINT PK_SBI_FUNCTION_INPUT_VARIABLE PRIMARY KEY(FUNCTION_UUID, VAR_NAME, ORGANIZATION);
ALTER TABLE SBI_FUNCTION_OUTPUT_COLUMN ADD CONSTRAINT PK_SBI_FUNCTION_OUTPUT_COLUMN PRIMARY KEY(FUNCTION_UUID, COL_NAME, ORGANIZATION);
ALTER TABLE SBI_OBJ_FUNCTION ADD CONSTRAINT XAK1SBI_OBJ_FUNCTION UNIQUE(BIOBJ_ID, FUNCTION_UUID, ORGANIZATION);

-- CREATE NEW FOREIGN KEYS
ALTER TABLE SBI_FUNCTION_INPUT_VARIABLE 	ADD CONSTRAINT FK_FUNCTION_INPUT_VARIABLES_1  		FOREIGN KEY (FUNCTION_UUID) 			REFERENCES SBI_CATALOG_FUNCTION(FUNCTION_UUID) ON DELETE  RESTRICT ON UPDATE  RESTRICT;
ALTER TABLE SBI_FUNCTION_INPUT_COLUMN	 	ADD CONSTRAINT FK_FUNCTION_INPUT_COLUMNS_1  		FOREIGN KEY (FUNCTION_UUID) 			REFERENCES SBI_CATALOG_FUNCTION(FUNCTION_UUID) ON DELETE  RESTRICT ON UPDATE  RESTRICT;
ALTER TABLE SBI_FUNCTION_OUTPUT_COLUMN	 	ADD CONSTRAINT FK_FUNCTION_OUTPUT_COLUMNS_1  		FOREIGN KEY (FUNCTION_UUID) 			REFERENCES SBI_CATALOG_FUNCTION(FUNCTION_UUID) ON DELETE  RESTRICT ON UPDATE  RESTRICT;

-- DROP OLD ID COLUMNS
ALTER TABLE SBI_CATALOG_FUNCTION DROP COLUMN FUNCTION_ID;
ALTER TABLE SBI_FUNCTION_INPUT_COLUMN DROP COLUMN FUNCTION_ID;
ALTER TABLE SBI_FUNCTION_INPUT_VARIABLE DROP COLUMN FUNCTION_ID;
ALTER TABLE SBI_FUNCTION_OUTPUT_COLUMN DROP COLUMN FUNCTION_ID;
ALTER TABLE SBI_OBJ_FUNCTION DROP COLUMN FUNCTION_ID;
